Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(262)

Unified Diff: src/gpu/GrRenderTargetPriv.h

Issue 2468653002: Remove GrStencilSettings from GrPipeline (Closed)
Patch Set: Remove GrStencilSettings from GrPipeline Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrRenderTarget.cpp ('k') | src/gpu/GrStencilSettings.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrRenderTargetPriv.h
diff --git a/src/gpu/GrRenderTargetPriv.h b/src/gpu/GrRenderTargetPriv.h
index 922d9b3071317b952561d15167c4995ddbe60672..19e72637f31459d89edb8d41fac246163b37c9e8 100644
--- a/src/gpu/GrRenderTargetPriv.h
+++ b/src/gpu/GrRenderTargetPriv.h
@@ -32,10 +32,10 @@ public:
int numStencilBits() const;
- // Finds a render target's multisample specs. The stencil settings are only needed in case the
- // info isn't cached and we need to flush the draw state in order to query it. They are not
- // expected to affect the multisample information itself.
- const GrGpu::MultisampleSpecs& getMultisampleSpecs(const GrStencilSettings& stencil) const;
+ // Finds a render target's multisample specs. The pipeline is only needed in case the info isn't
+ // cached and we need to flush the draw state in order to query it. The pipeline is not expected
+ // to affect the multisample information itself.
+ const GrGpu::MultisampleSpecs& getMultisampleSpecs(const GrPipeline&) const;
typedef GrRenderTarget::Flags Flags;
« no previous file with comments | « src/gpu/GrRenderTarget.cpp ('k') | src/gpu/GrStencilSettings.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698